#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: agave
# PROJECT HOMEPAGE 	: http://home.gna.org/colorscheme/
# SOURCES          	: http://download.gna.org/colorscheme/releases/
#
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION   : 2009-06-12 
#
# BUILD-ONLY DEPS	: -
# NOTES				: previously maintained by gapan.

### Checking for unbound variables
set -u

### Setting main variables
NAME="agave"
VERSION="0.4.4"
ARCH="i686"
CPU="i686"
BUILD=62.1
EXT="txz"

HOMEPAGE="http://home.gna.org/colorscheme/"
DESCRIPTION="colorscheme generator"
SRCLNK="http://download.gna.org/colorscheme/releases/$NAME-$VERSION.tar.bz2"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERSION
#~ ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		
	
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README TODO"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
#~ mkdir -p $PKGDIR/usr/share/applications
#~ mkdir -p $ICONDIR

### Checking if sources are present. If not, download them
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Building
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man --disable-scrollkeeper --disable-schemas-install || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
#~ find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Agave is a very simple application for the GNOME desktop that
$NAME: allows you to generate a variety of colorschemes from a single
$NAME: starting color. It is free software licensed under the open-source
$NAME: GPL License. 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
sed -i s:"agave-icon.png":"agave": $PKGDIR/usr/share/applications/$NAME.desktop

### Icon

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unneeded stuff 
# remove schemas... it shouldn't have installed them!
rm -fr $PKGDIR/etc

### Doinstall
cat > $PKGDIR/install/doinst.sh << EOF
# Update the scrollkeeper database
if [ -x usr/bin/scrollkeeper-update ]; then
        usr/bin/scrollkeeper-update > /dev/null 2>&1
fi
EOF

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT

### md5
cd $CWD
md5sum $PKG.$EXT > $PKG.md5

### dep
depfinder $PKG.$EXT > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK 
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
